Fedora Messaging — Fedora Messaging 1.1.0 documentation

# Fedora Messaging

This package provides tools and APIs to make using Fedora’s messaging infrastructure easier. These include a framework for declaring message schemas, a set of synchronous APIs to publish messages to AMQP brokers, a set of asynchronous APIs to consume messages, and services to easily run consumers.

This library is designed to be a replacement for the PyZMQ-backed fedmsg library.

## User Guide

- Installation
  - PyPI
  - Fedora
- Configuration
  - Generic Options
  - Publisher Options
  - Consumer Options
- Publishing
  - Overview
  - Introduction
  - Handling Errors
- Consumers
  - Introduction
  - Handling Errors
  - Blocking Calls
  - Halting
  - Consumer Configuration
  - State Across Messages
- Messages
  - Schema
  - Message Conventions
  - Packaging
- Testing
- Release Notes
  - v1.1.0 (2018-11-13)
  - v1.0.1 (2018-10-10)
  - v1.0.0 (2018-10-10)
  - v1.0.0b1
  - v1.0.0a1

### Command Line Interface Manuals

- fedora-messaging
  - Synopsis
  - Description
  - Options
  - Commands
  - Help

## Tutorial

- Using Fedora Messaging
  - Installation
  - Using the API
  - JSON schemas
  - Handling exceptions
  - Converting a fedmsg application

## API Documentation

- Developer Interface
  - Publishing
  - Subscribing
  - Signals
  - Message Schemas
  - Exceptions
  - Twisted
- Message Format
  - Overview
  - Headers
  - Body

## Contributor Guide

- Contributing
  - Guidelines